# -*- coding: utf-8 -*-
# ~ Jesse K. Rubin ~ Pretty Useful Python

from typing import Iterable
from typing import Union

Flint = Union[int, float]  # float or int
Paths = Iterable[str]  # iterable of path-strings
