# -*- coding: utf-8 -*-
# ~ Jesse K. Rubin ~ Pretty Useful Python

from typing import Any
from typing import Optional


def unescaped_str(arg_str: Any): ...

parser: Any

def main(args: Optional[Any] = ...) -> None: ...
