# -*- coding: utf-8 -*-
# ~ Jesse K. Rubin ~ Pretty Useful Python

from typing import Any
from typing import Dict
from typing import List


def safepath(path_str: str) -> str: ...
def lbytes(filepath: str) -> None: ...
def sstring(filepath: str, string: str) -> None: ...
def savings(filepath: str, string: str) -> None: ...
def sstr(filepath: str, string: str) -> None: ...
def lstring(filepath: str) -> Any: ...
def lstr(filepath: Any): ...
def sjson(filepath: str, data: Dict[str, List[str]], min: bool = ...) -> None: ...
def save_jasm(filepath: str, data: Dict[str, List[str]], min: bool = ...) -> None: ...
def sjasm(filepath: str, data: Dict[str, List[str]], min: bool = ...) -> None: ...
def spak(filepath: str, data: Dict[str, List[str]], min: bool = ...) -> None: ...
def ljson(filepath: str) -> Any: ...
def load_jasm(filepath: str) -> Dict[str, List[str]]: ...
def ljasm(filepath: str) -> Dict[str, List[str]]: ...
def lpak(filepath: str) -> Dict[str, List[str]]: ...
def touch(filepath: str) -> None: ...
def shebang(filepath: str) -> Any: ...
